==> amr-3.10.0-en-download.zip: amr-3.10.0-en/webhelp/amr-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database eventreplicatorforadabastargetadapteradministration
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var eventreplicatorforadabastargetadapteradministration = {
    baseurls: ["../"],
    varname: "eventreplicatorforadabastargetadapteradministration",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "amr/amra_ov.htm", title: "Event Replicator Target Adapter Administration",
              tree: [
                  { url: "amr/amr_ov.htm", title: "Event Replicator Target Adapter Administration Overview" },
                  { url: "amr/amr_reln.htm", title: "Release Notes" },
                  { url: "amr/amr_inst.htm", title: "Installing Event Replicator Target Adapter Administration" },
                  { url: "amr/amr_use.htm", title: "Using Event Replicator Target Adapter Administration" },
                  { url: "amr/rdbms.htm", title: "Supported Relational Databases *" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: eventreplicatorforadabastargetadapteradministration });

==> amr-4.0.0-en-download.zip: amr-4.0.0-en/webhelp/amr-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database eventreplicatortargetadapteradministration
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var eventreplicatortargetadapteradministration = {
    baseurls: ["../"],
    varname: "eventreplicatortargetadapteradministration",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "amr/amra_ov.htm", title: "Event Replicator Target Adapter Administration",
              tree: [
                  { url: "amr/amr_ov.htm", title: "Event Replicator Target Adapter Administration Overview" },
                  { url: "amr/amr_reln.htm", title: "Release Notes" },
                  { url: "amr/amr_inst.htm", title: "Installing Event Replicator Target Adapter Administration" },
                  { url: "amr/amr_use.htm", title: "Using Event Replicator Target Adapter Administration" },
                  { url: "amr/rdbms.htm", title: "Supported Relational Databases *" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: eventreplicatortargetadapteradministration });
